==> fr-server-7.1.jar: com/fr/web/core/js/chart.dataseries.js <==
FR.Chart.DataSeries=FR.extend(FR.Chart.ChartJsInit,{initConstants:function(c){c=c||{};this.points=[];if(c.dataPoints&&c.dataPoints.length>0&&c.dataPointType){var b=c.dataPoints||{};for(var a=0;a<b.length;a++){this.points[a]=new FR.Chart[c.dataPointType](b[a])}}this.seriesIndex=FR.pick(c.seriesIndex,0);this.seriesName=c.seriesName;this.seriesDragEnable=FR.pick(c.seriesDragEnable,false);this.paintState=FR.Chart.ChartPaintConstants.STATE_ENABLE;this.trendLineList=[];this.dataSeriesStyle=null;this.jsType="DataSeries";
this.glyph=null;this.lastGlyph=null;this.topFoldLine=null},addDataSeries:function(b){for(var a=0;a<this.points.length;a++){this.points[a].addDataPoint(b.points[a])}this.seriesName=this.seriesName+"&"+b.seriesName},createHotTooltip:function(b){for(var a=0;a<this.points.length;a++){if(this.points[a]){this.points[a].createHotTooltip(b)}}},getDataPointCount:function(){var a=0;if(this.points){a=this.points.length}return a},draw:function(a,e,c){if(this.paintState<=FR.Chart.ChartPaintConstants.STATE_UNENABLE||this.paintState==FR.Chart.ChartPaintConstants.STATE_TRANSPARENT){return
}if(this.glyph){this.glyph.draw(a,e,c)}var d=this.points;for(var b=0;b<this.getDataPointCount();b++){if(d[b]!=null){d[b].draw(a,e)}}},draw4Demo:function(a){if(this.glyph){this.glyph.draw4Demo(a)}var c=this.points;for(var b=0;b<this.getDataPointCount();b++){if(c[b]!=null){c[b].draw4Demo(a)}}},drawLabel:function(b,a){for(var c=0;c<this.getDataPointCount();c++){if(this.points[c]){this.points[c].drawLabel(b,a)}}},makeLabelVisible:function(a){for(var b=0;b<this.getDataPointCount();b++){if(this.points[b]){this.points[b].makeLabelVisible(a)
}}},getAnimateGlyph:function(c,b){if(this.paintState==FR.Chart.ChartPaintConstants.STATE_UNENABLE){return}if(this.trendLineList){this.trendLineAnimateGlyph=[];for(var a=0;a<this.trendLineList.length;a++){this.trendLineAnimateGlyph[a]=this.trendLineList[a].getAnimateGlyph(c,b)}}if(this.glyph||this.lastGlyph){this.animateGlyph=(this.glyph||this.lastGlyph).getAnimateGlyph(c,b,this.lastGlyph,this.paintState);if(!this.isPointAnimate){return}}var d=this.points;for(var a=0;a<this.getDataPointCount();a++){d[a].getAnimateGlyph(c,b,this.paintState)
}},getAnimateStepNumber:function(){var a=0;if(this.animateGlyph){a=this.animateGlyph.length}if(this.trendLineAnimateGlyph&&a<=0&&this.trendLineAnimateGlyph[0]){return this.trendLineAnimateGlyph[0].length}if(this.points&&a<=0){var b=0;while(b<this.points.length&&!this.points[b].animateGlyph){b++}if(b<this.points.length&&this.points[b].animateGlyph){return this.points[b].animateGlyph.length}}return a},findOnMoveGlyph:function(a,g){if(this.paintState<=FR.Chart.ChartPaintConstants.STATE_UNENABLE){return
}var c=this.glyph?this.glyph.getShape().getInteractivePath():null;if(this.seriesDragEnable&&g._isMouseDown&&g._needsMobileSeriesDrag&&FR.Chart.GraphHelper.isDrawingEnd){if(c&&c.containsPoint(a.x,a.y)){g._hasfound=true;g._lastHover=this}else{for(var e=0;e<this.getDataPointCount();e++){this.points[e].findOnMoveGlyph(a,g);if(g._hasfound){break}}}if(g._hasfound){g._draggingTarget=this;this.paintState=FR.Chart.ChartPaintConstants.STATE_TRANSPARENT}}else{this.nearByPoint=null;if(c&&c.containsPoint(a.x,a.y)){g._hasfound=true;
g._lastHover=this;var d=Number.MAX_VALUE;for(var e=0;e<this.getDataPointCount();e++){if(this.points[e].glyph){var f=this.points[e].glyph.getShape().getBounds2D();var b=this.getAbsLength(f,a);if(b<d&&this.points[e].tooltip!=null){d=b;this.nearByPoint=this.points[e]}}}}else{for(var e=0;e<this.getDataPointCount();e++){this.points[e].findOnMoveGlyph(a,g);if(g._hasfound){return}}}}},getAbsLength:function(c,b){if(!c||!b){return Number.MAX_VALUE}var a=c.x+c.width/2;var d=c.y+c.height/2;return(a-b.x)*(a-b.x)+(d-b.y)*(d-b.y)
},doOnMove:function(c,b){if(!(this.glyph.getShape() instanceof FR.Chart.Area3D)){FR.Chart.HighUtils.doFocus(this.glyph,c)}if(this.nearByPoint){var a=this.nearByPoint;FR.Chart.Tooltip.dataPointTip(a.tooltip,c,b,this.glyph&&this.glyph.toolTipBackground);if(a.glyph&&a.glyph.marker&&a.glyph.marker.getMarkerType){a.glyph.drawOnMove=true;a.glyph.draw(c);a.glyph.drawOnMove=false}else{FR.Chart.HighUtils.doFocus(a.glyph,c)}}},doTrendLineTooltip:function(e,d){if(this.paintState<=FR.Chart.ChartPaintConstants.STATE_UNENABLE){return
}if(this.trendLineList&&this.trendLineList.length>0){for(var b=0;b<this.trendLineList.length;b++){var c=this.trendLineList[b];var a=e.x;var h=c.calculator(a);var g=c.valueAxisGlyph.getPointValue4TrendLine(h,e.y);var f=new FR.Chart.TooltipString();f.formatValue(c.trendLineName+" : "+g);d[d.length]={text:[f],lineColor:c.lineStyleInfo.attrLineColor.lineColor}}}},drawAnimateGlyph:function(a,b){if(this.paintState==FR.Chart.ChartPaintConstants.STATE_UNENABLE||this.paintState==FR.Chart.ChartPaintConstants.STATE_TRANSPARENT){return
}if(this.animateGlyph&&this.animateGlyph.length>0&&b<this.animateGlyph.length){this.animateGlyph[b].draw(a)}var d=this.points;for(var c=0;c<this.getDataPointCount();c++){d[c].drawAnimateGlyph(a,b);if(d[c].dataPointStyle&&d[c].dataPointStyle.paintHighLight){d[c].dataPointStyle.paintHighLight(a)}}},drawAnimateGlyph4TrendLine:function(a,b){if(this.paintState<=FR.Chart.ChartPaintConstants.STATE_UNENABLE||this.paintState==FR.Chart.ChartPaintConstants.STATE_TRANSPARENT){return}if(this.trendLineAnimateGlyph[0]&&this.trendLineAnimateGlyph.length>0&&b<this.trendLineAnimateGlyph[0].length){for(var c=0;
c<this.trendLineAnimateGlyph.length;c++){if(this.trendLineAnimateGlyph[c]){var d=this.trendLineAnimateGlyph[c];if(d[b]){d[b].draw(a)}}}}}});FR.Chart.DataSeries4Area=FR.extend(FR.Chart.DataSeries,{getAnimateGlyph:function(b,a){if(this.paintState==FR.Chart.ChartPaintConstants.STATE_UNENABLE){return}if(this.topFoldLine&&(this.glyph||this.lastGlyph)){this.topFoldLineAnimateGlyph=(this.glyph||this.lastGlyph).getAnimateGlyph4TopFoldLine(b,a,this.topFoldLine,this.lastGlyph,this.paintState)}FR.Chart.DataSeries4Area.superclass.getAnimateGlyph.apply(this,[b,a])
},drawAnimateGlyph4TopFoldLine:function(a,b){if(this.paintState==FR.Chart.ChartPaintConstants.STATE_UNENABLE){return}if(this.topFoldLineAnimateGlyph&&this.topFoldLineAnimateGlyph.length>0&&b<this.topFoldLineAnimateGlyph.length){this.topFoldLineAnimateGlyph[b].draw(a)}}});

==> fr-server-7.1.12.jar: com/fr/web/core/js/chart.dataseries.js <==
FR.Chart.DataSeries=FR.extend(FR.Chart.ChartJsInit,{initConstants:function(c){c=c||{};this.points=[];if(c.dataPoints&&c.dataPoints.length>0&&c.dataPointType){var b=c.dataPoints||{};for(var a=0;a<b.length;a++){this.points[a]=new FR.Chart[c.dataPointType](b[a])}}this.seriesIndex=FR.pick(c.seriesIndex,0);this.seriesName=c.seriesName;this.seriesDragEnable=FR.pick(c.seriesDragEnable,false);this.paintState=FR.Chart.ChartPaintConstants.STATE_ENABLE;this.trendLineList=[];this.dataSeriesStyle=null;this.jsType="DataSeries";
this.glyph=null;this.lastGlyph=null;this.topFoldLine=null},addDataSeries:function(b){for(var a=0;a<this.points.length;a++){this.points[a].addDataPoint(b.points[a])}this.seriesName=this.seriesName+"&"+b.seriesName},createHotTooltip:function(b){for(var a=0;a<this.points.length;a++){if(this.points[a]){this.points[a].createHotTooltip(b)}}},getDataPointCount:function(){var a=0;if(this.points){a=this.points.length}return a},draw:function(a,e,c){if(this.paintState<=FR.Chart.ChartPaintConstants.STATE_UNENABLE||this.paintState==FR.Chart.ChartPaintConstants.STATE_TRANSPARENT){return
}if(this.glyph){this.glyph.draw(a,e,c)}var d=this.points;for(var b=0;b<this.getDataPointCount();b++){if(d[b]!=null){d[b].draw(a,e)}}},draw4Demo:function(a){if(this.glyph){this.glyph.draw4Demo(a)}var c=this.points;for(var b=0;b<this.getDataPointCount();b++){if(c[b]!=null){c[b].draw4Demo(a)}}},drawLabel:function(b,a){for(var c=0;c<this.getDataPointCount();c++){if(this.points[c]){this.points[c].drawLabel(b,a)}}},makeLabelVisible:function(a){for(var b=0;b<this.getDataPointCount();b++){if(this.points[b]){this.points[b].makeLabelVisible(a)
}}},getAnimateGlyph:function(c,b){if(this.paintState==FR.Chart.ChartPaintConstants.STATE_UNENABLE){return}if(this.trendLineList){this.trendLineAnimateGlyph=[];for(var a=0;a<this.trendLineList.length;a++){this.trendLineAnimateGlyph[a]=this.trendLineList[a].getAnimateGlyph(c,b)}}if(this.glyph||this.lastGlyph){this.animateGlyph=(this.glyph||this.lastGlyph).getAnimateGlyph(c,b,this.lastGlyph,this.paintState);if(!this.isPointAnimate){return}}var d=this.points;for(var a=0;a<this.getDataPointCount();a++){d[a].getAnimateGlyph(c,b,this.paintState)
}},getAnimateStepNumber:function(){var a=0;if(this.animateGlyph){a=this.animateGlyph.length}if(this.trendLineAnimateGlyph&&a<=0&&this.trendLineAnimateGlyph[0]){return this.trendLineAnimateGlyph[0].length}if(this.points&&a<=0){var b=0;while(b<this.points.length&&!this.points[b].animateGlyph){b++}if(b<this.points.length&&this.points[b].animateGlyph){return this.points[b].animateGlyph.length}}return a},findOnMoveGlyph:function(a,g){if(this.paintState<=FR.Chart.ChartPaintConstants.STATE_UNENABLE||this.paintState==FR.Chart.ChartPaintConstants.STATE_TRANSPARENT){return
}var c=this.glyph?this.glyph.getShape().getInteractivePath():null;if(this.seriesDragEnable&&g._isMouseDown&&g._needsMobileSeriesDrag&&FR.Chart.GraphHelper.isDrawingEnd){if(c&&c.containsPoint(a.x,a.y)){g._hasfound=true;g._lastHover=this}else{for(var e=0;e<this.getDataPointCount();e++){this.points[e].findOnMoveGlyph(a,g);if(g._hasfound){break}}}if(g._hasfound){g._draggingTarget=this;this.paintState=FR.Chart.ChartPaintConstants.STATE_TRANSPARENT}}else{this.nearByPoint=null;if(c&&c.containsPoint(a.x,a.y)){g._hasfound=true;
g._lastHover=this;var d=Number.MAX_VALUE;for(var e=0;e<this.getDataPointCount();e++){if(this.points[e].glyph){var f=this.points[e].glyph.getShape().getBounds2D();var b=this.getAbsLength(f,a);if(b<d&&this.points[e].tooltip!=null){d=b;this.nearByPoint=this.points[e]}}}}else{for(var e=0;e<this.getDataPointCount();e++){this.points[e].findOnMoveGlyph(a,g);if(g._hasfound){return}}}}},getAbsLength:function(c,b){if(!c||!b){return Number.MAX_VALUE}var a=c.x+c.width/2;var d=c.y+c.height/2;return(a-b.x)*(a-b.x)+(d-b.y)*(d-b.y)
},doOnMove:function(c,b){if(!(this.glyph.getShape() instanceof FR.Chart.Area3D)){FR.Chart.HighUtils.doFocus(this.glyph,c)}if(this.nearByPoint){var a=this.nearByPoint;FR.Chart.Tooltip.dataPointTip(a.tooltip,c,b,this.glyph&&this.glyph.toolTipBackground);if(a.glyph&&a.glyph.marker&&a.glyph.marker.getMarkerType){a.glyph.drawOnMove=true;a.glyph.draw(c);a.glyph.drawOnMove=false}else{FR.Chart.HighUtils.doFocus(a.glyph,c)}}},doTrendLineTooltip:function(e,d){if(this.paintState<=FR.Chart.ChartPaintConstants.STATE_UNENABLE){return
}if(this.trendLineList&&this.trendLineList.length>0){for(var b=0;b<this.trendLineList.length;b++){var c=this.trendLineList[b];var a=e.x;var h=c.calculator(a);var g=c.valueAxisGlyph.getPointValue4TrendLine(h,e.y);var f=new FR.Chart.TooltipString();f.formatValue(c.trendLineName+" : "+g);d[d.length]={text:[f],lineColor:c.lineStyleInfo.attrLineColor.lineColor}}}},drawAnimateGlyph:function(a,b){if(this.paintState==FR.Chart.ChartPaintConstants.STATE_UNENABLE||this.paintState==FR.Chart.ChartPaintConstants.STATE_TRANSPARENT){return
}if(this.animateGlyph&&this.animateGlyph.length>0&&b<this.animateGlyph.length){this.animateGlyph[b].draw(a)}var d=this.points;for(var c=0;c<this.getDataPointCount();c++){d[c].drawAnimateGlyph(a,b);if(d[c].dataPointStyle&&d[c].dataPointStyle.paintHighLight){d[c].dataPointStyle.paintHighLight(a)}}},drawAnimateGlyph4TrendLine:function(a,b){if(this.paintState<=FR.Chart.ChartPaintConstants.STATE_UNENABLE||this.paintState==FR.Chart.ChartPaintConstants.STATE_TRANSPARENT){return}if(this.trendLineAnimateGlyph[0]&&this.trendLineAnimateGlyph.length>0&&b<this.trendLineAnimateGlyph[0].length){for(var c=0;
c<this.trendLineAnimateGlyph.length;c++){if(this.trendLineAnimateGlyph[c]){var d=this.trendLineAnimateGlyph[c];if(d[b]){d[b].draw(a)}}}}}});FR.Chart.DataSeries4Area=FR.extend(FR.Chart.DataSeries,{getAnimateGlyph:function(b,a){if(this.paintState==FR.Chart.ChartPaintConstants.STATE_UNENABLE){return}if(this.topFoldLine&&(this.glyph||this.lastGlyph)){this.topFoldLineAnimateGlyph=(this.glyph||this.lastGlyph).getAnimateGlyph4TopFoldLine(b,a,this.topFoldLine,this.lastGlyph,this.paintState)}FR.Chart.DataSeries4Area.superclass.getAnimateGlyph.apply(this,[b,a])
},drawAnimateGlyph4TopFoldLine:function(a,b){if(this.paintState==FR.Chart.ChartPaintConstants.STATE_UNENABLE){return}if(this.topFoldLineAnimateGlyph&&this.topFoldLineAnimateGlyph.length>0&&b<this.topFoldLineAnimateGlyph.length){this.topFoldLineAnimateGlyph[b].draw(a)}}});
